# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import httpx
import pydantic

from ...core.api_error import ApiError
from ...errors.conflict_error import ConflictError
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.climate_returner import ClimateReturner
from ...types.http_error import HttpError
from ...types.http_validation_error import HttpValidationError


class AtmosphericClient:
    def __init__(self, *, environment: str):
        self._environment = environment

    def get_climate_data(
        self,
        project_id: str,
        *,
        scenario: str,
        period: typing.Optional[str] = None,
        validate: typing.Optional[bool] = None,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
    ) -> ClimateReturner:
        _response = httpx.request(
            "GET",
            urllib.parse.urljoin(f"{self._environment}/", f"projects/{project_id}/climate"),
            params={
                "scenario": scenario,
                "period": period,
                "validate": validate,
                "start_date": start_date,
                "end_date": end_date,
            },
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ClimateReturner, _response.json())  # type: ignore
        if _response.status_code == 409:
            raise ConflictError(pydantic.parse_obj_as(HttpError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncAtmosphericClient:
    def __init__(self, *, environment: str):
        self._environment = environment

    async def get_climate_data(
        self,
        project_id: str,
        *,
        scenario: str,
        period: typing.Optional[str] = None,
        validate: typing.Optional[bool] = None,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
    ) -> ClimateReturner:
        async with httpx.AsyncClient() as _client:
            _response = await _client.request(
                "GET",
                urllib.parse.urljoin(f"{self._environment}/", f"projects/{project_id}/climate"),
                params={
                    "scenario": scenario,
                    "period": period,
                    "validate": validate,
                    "start_date": start_date,
                    "end_date": end_date,
                },
                timeout=60,
            )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ClimateReturner, _response.json())  # type: ignore
        if _response.status_code == 409:
            raise ConflictError(pydantic.parse_obj_as(HttpError, _response.json()))  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic.parse_obj_as(HttpValidationError, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
